@@ -32,7 +32,7 @@ var (
 )
 
 func loadTestdataBeforeFunc(path string, filename string, content string) func(ctx *core.BeforeFuncCtx) error {
-	return func(ctx *core.BeforeFuncCtx) error {
+	return func(_ *core.BeforeFuncCtx) error {
 		err := os.WriteFile(filepath.Join(path, filename), []byte(content), 0600)
 		if err != nil {
 			return err
@@ -42,7 +42,7 @@ func loadTestdataBeforeFunc(path string, filename string, content string) func(c
 }
 
 func mkdirAllBeforeFunc(path string) func(ctx *core.BeforeFuncCtx) error {
-	return func(ctx *core.BeforeFuncCtx) error {
+	return func(_ *core.BeforeFuncCtx) error {
 		err := os.MkdirAll(path, 0700)
 		if err != nil {
 			return err
