@@ -66,7 +66,7 @@ func serverCreateCommand() *core.Command {
 				Short:    "Server commercial type (help: https://www.scaleway.com/en/docs/compute/instances/reference-content/choosing-instance-type/)",
 				Default:  core.DefaultValueSetter("DEV1-S"),
 				Required: true,
-				ValidateFunc: func(argSpec *core.ArgSpec, value interface{}) error {
+				ValidateFunc: func(_ *core.ArgSpec, _ interface{}) error {
 					// Allow all commercial types
 					return nil
 				},
@@ -104,11 +104,11 @@ func serverCreateCommand() *core.Command {
 			},
 			{
 				Name:  "security-group-id",
-				Short: "The security group ID it use for this server",
+				Short: "The security group ID used for this server",
 			},
 			{
 				Name:  "placement-group-id",
-				Short: "The placement group ID in witch the server has to be created",
+				Short: "The placement group ID in which the server has to be created",
 			},
 			{
 				Name:  "bootscript-id",
