@@ -6,6 +6,8 @@ import (
 	"github.com/alecthomas/assert"
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/interactive"
+	blockCli "github.com/scaleway/scaleway-cli/v2/internal/namespaces/block/v1alpha1"
+	block "github.com/scaleway/scaleway-sdk-go/api/block/v1alpha1"
 	"github.com/scaleway/scaleway-sdk-go/api/instance/v1"
 	"github.com/scaleway/scaleway-sdk-go/scw"
 	"github.com/stretchr/testify/require"
@@ -16,7 +18,7 @@ func Test_ServerVolumeUpdate(t *testing.T) {
 		t.Run("simple block volume", core.Test(&core.TestConfig{
 			Commands: GetCommands(),
 			BeforeFunc: core.BeforeFuncCombine(
-				createServer("Server"),
+				createServerBionic("Server"),
 				createVolume("Volume", 10, instance.VolumeVolumeTypeBSSD),
 			),
 			Cmd: "scw instance server attach-volume server-id={{ .Server.ID }} volume-id={{ .Volume.ID }}",
@@ -33,7 +35,7 @@ func Test_ServerVolumeUpdate(t *testing.T) {
 		t.Run("simple local volume", core.Test(&core.TestConfig{
 			Commands: GetCommands(),
 			BeforeFunc: core.BeforeFuncCombine(
-				createServer("Server"),
+				createServerBionic("Server"),
 				createVolume("Volume", 10, instance.VolumeVolumeTypeLSSD),
 			),
 			Cmd: "scw instance server attach-volume server-id={{ .Server.ID }} volume-id={{ .Volume.ID }}",
@@ -49,7 +51,7 @@ func Test_ServerVolumeUpdate(t *testing.T) {
 
 		t.Run("invalid volume UUID", core.Test(&core.TestConfig{
 			Commands:   GetCommands(),
-			BeforeFunc: createServer("Server"),
+			BeforeFunc: createServerBionic("Server"),
 			Cmd:        "scw instance server attach-volume server-id={{ .Server.ID }} volume-id=11111111-1111-1111-1111-111111111111",
 			Check: core.TestCheckCombine(
 				core.TestCheckGolden(),
@@ -79,7 +81,7 @@ func Test_ServerVolumeUpdate(t *testing.T) {
 
 		t.Run("invalid volume UUID", core.Test(&core.TestConfig{
 			Commands:   GetCommands(),
-			BeforeFunc: createServer("Server"),
+			BeforeFunc: createServerBionic("Server"),
 			Cmd:        "scw instance server detach-volume volume-id=11111111-1111-1111-1111-111111111111",
 			Check: core.TestCheckCombine(
 				core.TestCheckGolden(),
@@ -95,7 +97,7 @@ func Test_ServerUpdateCustom(t *testing.T) {
 	// IP cases.
 	t.Run("Try to remove ip from server without ip", core.Test(&core.TestConfig{
 		Commands:   GetCommands(),
-		BeforeFunc: createServer("Server"),
+		BeforeFunc: createServerBionic("Server"),
 		Cmd:        "scw instance server update {{ .Server.ID }} ip=none",
 		Check: core.TestCheckCombine(
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
@@ -109,7 +111,7 @@ func Test_ServerUpdateCustom(t *testing.T) {
 	t.Run("Update server ip from server without ip", core.Test(&core.TestConfig{
 		Commands: GetCommands(),
 		BeforeFunc: core.BeforeFuncCombine(
-			createServer("Server"),
+			createServerBionic("Server"),
 			createIP("IP"),
 		),
 		Cmd: "scw instance server update {{ .Server.ID }} ip={{ .IP.Address }}",
@@ -125,7 +127,7 @@ func Test_ServerUpdateCustom(t *testing.T) {
 	t.Run("Update server ip from server with ip", core.Test(&core.TestConfig{
 		Commands: GetCommands(),
 		BeforeFunc: core.BeforeFuncCombine(
-			createServer("Server"),
+			createServerBionic("Server"),
 			createIP("IP1"),
 			createIP("IP2"),
 
@@ -205,7 +207,7 @@ func Test_ServerUpdateCustom(t *testing.T) {
 		t.Run("valid simple block volume", core.Test(&core.TestConfig{
 			Commands: GetCommands(),
 			BeforeFunc: core.BeforeFuncCombine(
-				createServer("Server"),
+				createServerBionic("Server"),
 				createVolume("Volume", 10, instance.VolumeVolumeTypeBSSD),
 			),
 			Cmd: `scw instance server update {{ .Server.ID }} volume-ids.0={{ (index .Server.Volumes "0").ID }} volume-ids.1={{ .Volume.ID }}`,
@@ -294,81 +296,28 @@ func Test_ServerDelete(t *testing.T) {
 		DisableParallel: true,
 	}))
 
-	interactive.IsInteractive = false
-}
-
-// These tests needs to be run in sequence
-// since they are using the interactive print
-func Test_ServerTerminate(t *testing.T) {
-	interactive.IsInteractive = true
-
-	t.Run("without IP", core.Test(&core.TestConfig{
-		Commands:   GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create image=ubuntu-bionic -w"),
-		Cmd:        `scw instance server terminate {{ .Server.ID }}`,
+	t.Run("with sbs volumes", core.Test(&core.TestConfig{
+		Commands: core.NewCommandsMerge(
+			GetCommands(),
+			blockCli.GetCommands(),
+		),
+		BeforeFunc: core.BeforeFuncCombine(
+			core.ExecStoreBeforeCmd("BlockVolume", "scw block volume create perf-iops=5000 from-empty.size=10G name=cli-test-server-delete-with-sbs-volumes"),
+			core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu-jammy"),
+			core.ExecBeforeCmd("scw instance server attach-volume server-id={{ .Server.ID }} volume-id={{ .BlockVolume.ID }}"),
+		),
+		Cmd: `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=all`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(0),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				api := instance.NewAPI(ctx.Client)
-				server := ctx.Meta["Server"].(*instance.Server)
-				_, err := api.GetIP(&instance.GetIPRequest{
-					IP: server.PublicIP.ID,
+				api := block.NewAPI(ctx.Client)
+				blockVolume := ctx.Meta["BlockVolume"].(*block.Volume)
+				resp, err := api.GetVolume(&block.GetVolumeRequest{
+					Zone:     blockVolume.Zone,
+					VolumeID: blockVolume.ID,
 				})
-				assert.NoError(t, err)
-			},
-		),
-		AfterFunc:       core.ExecAfterCmd(`scw instance ip delete {{ index .Server.PublicIP.ID }}`),
-		DisableParallel: true,
-	}))
-
-	t.Run("with IP", core.Test(&core.TestConfig{
-		Commands:   GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create image=ubuntu-bionic -w"),
-		Cmd:        `scw instance server terminate {{ .Server.ID }} with-ip=true`,
-		Check: core.TestCheckCombine(
-			core.TestCheckGolden(),
-			core.TestCheckExitCode(0),
-			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				api := instance.NewAPI(ctx.Client)
-				server := ctx.Meta["Server"].(*instance.Server)
-				_, err := api.GetIP(&instance.GetIPRequest{
-					IP: server.PublicIP.ID,
-				})
-				require.IsType(t, &scw.ResponseError{}, err)
-				assert.Equal(t, 403, err.(*scw.ResponseError).StatusCode)
-			},
-		),
-		DisableParallel: true,
-	}))
-
-	t.Run("without block", core.Test(&core.TestConfig{
-		Commands:   GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create image=ubuntu-bionic additional-volumes.0=block:10G -w"),
-		Cmd:        `scw instance server terminate {{ .Server.ID }} with-ip=true with-block=false`,
-		Check: core.TestCheckCombine(
-			core.TestCheckGolden(),
-			core.TestCheckExitCode(0),
-		),
-		AfterFunc:       core.ExecAfterCmd(`scw instance volume delete {{ (index .Server.Volumes "1").ID }}`),
-		DisableParallel: true,
-	}))
-
-	t.Run("with block", core.Test(&core.TestConfig{
-		Commands:   GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create image=ubuntu-bionic additional-volumes.0=block:10G -w"),
-		Cmd:        `scw instance server terminate {{ .Server.ID }} with-ip=true with-block=true -w`,
-		Check: core.TestCheckCombine(
-			core.TestCheckGolden(),
-			core.TestCheckExitCode(0),
-			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				api := instance.NewAPI(ctx.Client)
-				server := ctx.Meta["Server"].(*instance.Server)
-				_, err := api.GetVolume(&instance.GetVolumeRequest{
-					VolumeID: server.Volumes["0"].ID,
-					Zone:     server.Zone,
-				})
-				require.IsType(t, &scw.ResourceNotFoundError{}, err)
+				assert.Error(t, err, "%v", resp)
 			},
 		),
 		DisableParallel: true,
@@ -376,21 +325,3 @@ func Test_ServerTerminate(t *testing.T) {
 
 	interactive.IsInteractive = false
 }
-
-// These tests needs to be run in sequence
-// since they are using the interactive print
-func Test_ServerBackup(t *testing.T) {
-	t.Run("simple", core.Test(&core.TestConfig{
-		Commands:   GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", "scw instance server create stopped=true image=ubuntu-bionic"),
-		Cmd:        `scw instance server backup {{ .Server.ID }} name=backup`,
-		Check: core.TestCheckCombine(
-			core.TestCheckGolden(),
-			core.TestCheckExitCode(0),
-		),
-		AfterFunc: core.AfterFuncCombine(
-			core.ExecAfterCmd("scw instance image delete {{ .CmdResult.Image.ID }} with-snapshots=true"),
-			core.ExecAfterCmd("scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=local"),
-		),
-	}))
-}
