@@ -2,6 +2,7 @@ package instance
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"reflect"
 	"strings"
@@ -17,6 +18,8 @@ import (
 	"github.com/scaleway/scaleway-sdk-go/scw"
 )
 
+const configFileGeneratedMessage = "Config file was generated to"
+
 type sshConfigServer struct {
 	Name              string
 	Address           string
@@ -110,12 +113,12 @@ Do you want the include statement to be added at the beginning of your file ?`,
 			// Generated config needs an include statement in default config
 			included, err := sshconfig.ConfigIsIncluded(homeDir)
 			if err != nil {
-				if err == sshconfig.ErrFileNotFound {
+				if errors.Is(err, sshconfig.ErrFileNotFound) {
 					includePrompt += "\nFile was not found, it will be created"
 				} else {
 					logger.Warningf("Failed to check default config file, skipping include prompt\n")
 					return &core.SuccessResult{
-						Message: "Config file was generated to " + configFilePath,
+						Message: configFileGeneratedMessage + " " + configFilePath,
 					}, nil
 				}
 			}
@@ -123,7 +126,7 @@ Do you want the include statement to be added at the beginning of your file ?`,
 			// Generated config is already included
 			if included {
 				return &core.SuccessResult{
-					Message: "Config file was generated to " + configFilePath,
+					Message: configFileGeneratedMessage + " " + configFilePath,
 				}, nil
 			}
 
@@ -135,7 +138,7 @@ Do you want the include statement to be added at the beginning of your file ?`,
 			if err != nil {
 				logger.Warningf("Failed to prompt, skipping include\n")
 				return &core.SuccessResult{
-					Message: "Config file was generated to " + configFilePath,
+					Message: configFileGeneratedMessage + " " + configFilePath,
 				}, nil
 			}
 
@@ -147,7 +150,7 @@ Do you want the include statement to be added at the beginning of your file ?`,
 			}
 
 			return &core.SuccessResult{
-				Message: "Config file was generated to " + configFilePath,
+				Message: configFileGeneratedMessage + " " + configFilePath,
 			}, nil
 		},
 		Groups: []string{"workflow"},
@@ -292,6 +295,9 @@ func sshConfigBastionHosts(ctx context.Context, args *sshConfigInstallRequest, s
 		Zone: args.Zone,
 	}, reqOpts...)
 	if err != nil {
+		if strings.Contains(err.Error(), "unknown service") {
+			return nil, nil
+		}
 		// TODO: check permissions and print warning
 		return nil, err
 	}
