@@ -4,11 +4,13 @@ import (
 	"context"
 	"fmt"
 	"reflect"
+	"time"
 
 	"github.com/fatih/color"
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/human"
 	"github.com/scaleway/scaleway-sdk-go/api/instance/v1"
+	"github.com/scaleway/scaleway-sdk-go/scw"
 )
 
 //
@@ -96,3 +98,47 @@ func volumeListBuilder(c *core.Command) *core.Command {
 	})
 	return c
 }
+
+type volumeWaitRequest struct {
+	Zone     scw.Zone
+	VolumeID string
+	Timeout  time.Duration
+}
+
+func volumeWaitCommand() *core.Command {
+	return &core.Command{
+		Short:     `Wait for volume to reach a stable state`,
+		Long:      `Wait for volume to reach a stable state. This is similar to using --wait flag on other action commands, but without requiring a new action on the volume.`,
+		Namespace: "instance",
+		Resource:  "volume",
+		Verb:      "wait",
+		Groups:    []string{"workflow"},
+		ArgsType:  reflect.TypeOf(volumeWaitRequest{}),
+		Run: func(ctx context.Context, argsI interface{}) (i interface{}, err error) {
+			args := argsI.(*volumeWaitRequest)
+
+			return instance.NewAPI(core.ExtractClient(ctx)).WaitForVolume(&instance.WaitForVolumeRequest{
+				Zone:          args.Zone,
+				VolumeID:      args.VolumeID,
+				Timeout:       scw.TimeDurationPtr(args.Timeout),
+				RetryInterval: core.DefaultRetryInterval,
+			})
+		},
+		ArgSpecs: core.ArgSpecs{
+			core.WaitTimeoutArgSpec(serverActionTimeout),
+			{
+				Name:       "volume-id",
+				Short:      `ID of the volume affected by the action.`,
+				Required:   true,
+				Positional: true,
+			},
+			core.ZoneArgSpec(),
+		},
+		Examples: []*core.Example{
+			{
+				Short:    "Wait for a volume to reach a stable state",
+				ArgsJSON: `{"volume_id": "11111111-1111-1111-1111-111111111111"}`,
+			},
+		},
+	}
+}
