@@ -44,8 +44,8 @@ const (
 )
 
 func clusterMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error) {
-	type tmp k8s.Cluster
-	cluster := tmp(i.(k8s.Cluster))
+	type humanCluster k8s.Cluster
+	cluster := humanCluster(i.(k8s.Cluster))
 
 	// Sections
 	opt.Sections = []*human.MarshalSection{
@@ -71,6 +71,26 @@ func clusterMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error)
 	return str, nil
 }
 
+func clusterAvailableTypesListMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string, error) {
+	type humanResponse k8s.ListClusterAvailableTypesResponse
+	types := humanResponse(i.(k8s.ListClusterAvailableTypesResponse))
+
+	// Sections
+	opt.Sections = []*human.MarshalSection{
+		{
+			FieldName: "ClusterTypes",
+			Title:     "Cluster Types",
+		},
+	}
+
+	str, err := human.Marshal(types, opt)
+	if err != nil {
+		return "", err
+	}
+
+	return str, nil
+}
+
 func clusterAvailableVersionsListBuilder(c *core.Command) *core.Command {
 	c.AddInterceptors(func(ctx context.Context, argsI interface{}, runner core.CommandRunner) (interface{}, error) {
 		originalRes, err := runner(ctx, argsI)
@@ -90,8 +110,12 @@ func clusterCreateBuilder(c *core.Command) *core.Command {
 
 	c.ArgSpecs.GetByName("cni").Default = core.DefaultValueSetter("cilium")
 	c.ArgSpecs.GetByName("version").Default = core.DefaultValueSetter("latest")
+
 	c.ArgSpecs.GetByName("private-network-id").Short += ". For Kapsule clusters, if none is provided, a private network will be created"
 
+	c.ArgSpecs.GetByName("version").AutoCompleteFunc = autocompleteK8SVersion
+	c.ArgSpecs.GetByName("type").AutoCompleteFunc = autocompleteClusterType
+
 	c.Interceptor = func(ctx context.Context, argsI interface{}, runner core.CommandRunner) (interface{}, error) {
 		args := argsI.(*k8s.CreateClusterRequest)
 
@@ -118,6 +142,26 @@ func clusterCreateBuilder(c *core.Command) *core.Command {
 		var pn *vpc.PrivateNetwork
 		var err error
 
+		types, err := k8sAPI.ListClusterTypes(&k8s.ListClusterTypesRequest{
+			Region: request.Region,
+		})
+		if err != nil {
+			return nil, err
+		}
+		if request.Type != "" {
+			validType := false
+			validTypes := []string(nil)
+			for _, clusterType := range types.ClusterTypes {
+				validTypes = append(validTypes, clusterType.Name)
+				if clusterType.Name == request.Type {
+					validType = true
+				}
+			}
+			if !validType {
+				return nil, fmt.Errorf("invalid cluster type %q, must be one of %v", request.Type, validTypes)
+			}
+		}
+
 		if request.Type == "" || strings.HasPrefix(request.Type, "kapsule") {
 			if request.PrivateNetworkID == nil {
 				pn, err = vpcAPI.CreatePrivateNetwork(&vpc.CreatePrivateNetworkRequest{
@@ -393,3 +437,55 @@ func k8sClusterWaitCommand() *core.Command {
 		},
 	}
 }
+
+// Caching ListClusterTypes response for shell completion
+var completeListClusterTypesCache *k8s.ListClusterTypesResponse
+
+func autocompleteClusterType(ctx context.Context, prefix string) core.AutocompleteSuggestions {
+	suggestions := core.AutocompleteSuggestions(nil)
+
+	client := core.ExtractClient(ctx)
+	api := k8s.NewAPI(client)
+
+	if completeListClusterTypesCache == nil {
+		res, err := api.ListClusterTypes(&k8s.ListClusterTypesRequest{})
+		if err != nil {
+			return nil
+		}
+		completeListClusterTypesCache = res
+	}
+
+	for _, clusterType := range completeListClusterTypesCache.ClusterTypes {
+		if strings.HasPrefix(clusterType.Name, prefix) {
+			suggestions = append(suggestions, clusterType.Name)
+		}
+	}
+
+	return suggestions
+}
+
+// Caching ListK8SVersions response for shell completion
+var completeListK8SVersionsCache *k8s.ListVersionsResponse
+
+func autocompleteK8SVersion(ctx context.Context, prefix string) core.AutocompleteSuggestions {
+	suggestions := core.AutocompleteSuggestions(nil)
+
+	client := core.ExtractClient(ctx)
+	api := k8s.NewAPI(client)
+
+	if completeListK8SVersionsCache == nil {
+		res, err := api.ListVersions(&k8s.ListVersionsRequest{})
+		if err != nil {
+			return nil
+		}
+		completeListK8SVersionsCache = res
+	}
+
+	for _, version := range completeListK8SVersionsCache.Versions {
+		if strings.HasPrefix(version.Name, prefix) {
+			suggestions = append(suggestions, version.Name)
+		}
+	}
+
+	return suggestions
+}
