@@ -13,6 +13,9 @@ func GetCommands() *core.Commands {
 	human.RegisterMarshalerFunc(rdb.BackupSchedule{}, backupScheduleMarshalerFunc)
 	human.RegisterMarshalerFunc(backupDownloadResult{}, backupResultMarshallerFunc)
 	human.RegisterMarshalerFunc(createInstanceResult{}, createInstanceResultMarshalerFunc)
+	human.RegisterMarshalerFunc(rdbACLCustomResult{}, rdbACLCustomResultMarshalerFunc)
+	human.RegisterMarshalerFunc(rdbEndpointCustomResult{}, rdbEndpointCustomResultMarshalerFunc)
+	human.RegisterMarshalerFunc(rdb.DatabaseBackup{}, backupExportDisplayBuilder)
 
 	human.RegisterMarshalerFunc(rdb.InstanceStatus(""), human.EnumMarshalFunc(instanceStatusMarshalSpecs))
 	human.RegisterMarshalerFunc(rdb.DatabaseBackupStatus(""), human.EnumMarshalFunc(backupStatusMarshalSpecs))
@@ -21,33 +24,43 @@ func GetCommands() *core.Commands {
 	human.RegisterMarshalerFunc(rdb.ACLRuleAction(""), human.EnumMarshalFunc(aclRuleActionMarshalSpecs))
 
 	cmds.Merge(core.NewCommands(
-		instanceWaitCommand(),
-		instanceConnectCommand(),
-		backupWaitCommand(),
+		aclEditCommand(),
 		backupDownloadCommand(),
+		backupWaitCommand(),
+		databaseGetURLCommand(),
+		endpointListCommand(),
 		engineSettingsCommand(),
+		instanceConnectCommand(),
+		instanceWaitCommand(),
+		userGetURLCommand(),
 	))
 	cmds.MustFind("rdb", "acl", "add").Override(aclAddBuilder)
 	cmds.MustFind("rdb", "acl", "delete").Override(aclDeleteBuilder)
+	cmds.MustFind("rdb", "acl", "set").Override(aclSetBuilder)
 
 	cmds.MustFind("rdb", "backup", "create").Override(backupCreateBuilder)
 	cmds.MustFind("rdb", "backup", "export").Override(backupExportBuilder)
+	cmds.MustFind("rdb", "backup", "list").Override(backupListBuilder)
 	cmds.MustFind("rdb", "backup", "restore").Override(backupRestoreBuilder)
 
-	cmds.MustFind("rdb", "instance", "create").Override(instanceCreateBuilder)
-	cmds.MustFind("rdb", "instance", "clone").Override(instanceCloneBuilder)
-	cmds.MustFind("rdb", "instance", "upgrade").Override(instanceUpgradeBuilder)
-	cmds.MustFind("rdb", "instance", "update").Override(instanceUpdateBuilder)
-	cmds.MustFind("rdb", "instance", "get").Override(instanceGetBuilder)
-	cmds.MustFind("rdb", "instance", "delete").Override(instanceDeleteBuilder)
+	cmds.MustFind("rdb", "endpoint", "create").Override(endpointCreateBuilder)
+	cmds.MustFind("rdb", "endpoint", "delete").Override(endpointDeleteBuilder)
+	cmds.MustFind("rdb", "endpoint", "get").Override(endpointGetBuilder)
 
 	cmds.MustFind("rdb", "engine", "list").Override(engineListBuilder)
 
-	cmds.MustFind("rdb", "user", "list").Override(userListBuilder)
+	cmds.MustFind("rdb", "instance", "create").Override(instanceCreateBuilder)
+	cmds.MustFind("rdb", "instance", "clone").Override(instanceCloneBuilder)
+	cmds.MustFind("rdb", "instance", "delete").Override(instanceDeleteBuilder)
+	cmds.MustFind("rdb", "instance", "get").Override(instanceGetBuilder)
+	cmds.MustFind("rdb", "instance", "update").Override(instanceUpdateBuilder)
+	cmds.MustFind("rdb", "instance", "upgrade").Override(instanceUpgradeBuilder)
+
 	cmds.MustFind("rdb", "user", "create").Override(userCreateBuilder)
+	cmds.MustFind("rdb", "user", "list").Override(userListBuilder)
 	cmds.MustFind("rdb", "user", "update").Override(userUpdateBuilder)
 
-	cmds.MustFind("rdb", "backup", "list").Override(backupListBuilder)
+	cmds.MustFind("rdb", "log", "prepare").Override(logPrepareBuilder)
 
 	return cmds
 }
