@@ -80,7 +80,7 @@ func backupWaitCommand() *core.Command {
 
 func backupCreateBuilder(c *core.Command) *core.Command {
 	timeout := backupActionTimeout
-	c.WaitFunc = func(ctx context.Context, argsI, respI interface{}) (interface{}, error) {
+	c.WaitFunc = func(ctx context.Context, _, respI interface{}) (interface{}, error) {
 		api := rdb.NewAPI(core.ExtractClient(ctx))
 		return api.WaitForDatabaseBackup(&rdb.WaitForDatabaseBackupRequest{
 			DatabaseBackupID: respI.(*rdb.DatabaseBackup).ID,
@@ -95,7 +95,7 @@ func backupCreateBuilder(c *core.Command) *core.Command {
 
 func backupExportBuilder(c *core.Command) *core.Command {
 	timeout := backupActionTimeout
-	c.WaitFunc = func(ctx context.Context, argsI, respI interface{}) (interface{}, error) {
+	c.WaitFunc = func(ctx context.Context, _, respI interface{}) (interface{}, error) {
 		api := rdb.NewAPI(core.ExtractClient(ctx))
 		return api.WaitForDatabaseBackup(&rdb.WaitForDatabaseBackupRequest{
 			DatabaseBackupID: respI.(*rdb.DatabaseBackup).ID,
@@ -110,7 +110,7 @@ func backupExportBuilder(c *core.Command) *core.Command {
 
 func backupRestoreBuilder(c *core.Command) *core.Command {
 	timeout := backupActionTimeout
-	c.WaitFunc = func(ctx context.Context, argsI, respI interface{}) (interface{}, error) {
+	c.WaitFunc = func(ctx context.Context, _, respI interface{}) (interface{}, error) {
 		api := rdb.NewAPI(core.ExtractClient(ctx))
 		return api.WaitForDatabaseBackup(&rdb.WaitForDatabaseBackupRequest{
 			DatabaseBackupID: respI.(*rdb.DatabaseBackup).ID,
@@ -233,6 +233,99 @@ func backupListBuilder(c *core.Command) *core.Command {
 	return c
 }
 
+func backupExportDisplayBuilder(i interface{}, opt *human.MarshalOpt) (string, error) {
+	databaseBackup := i.(rdb.DatabaseBackup)
+
+	type customDisplayBackup struct {
+		ID           string                   `json:"ID"`
+		InstanceID   string                   `json:"instance_ID"`
+		DatabaseName string                   `json:"database_name"`
+		Name         string                   `json:"name"`
+		Status       rdb.DatabaseBackupStatus `json:"status"`
+		Size         *scw.Size                `json:"size"`
+		ExpiresAt    *time.Time               `json:"expires_at"`
+		CreatedAt    *time.Time               `json:"created_at"`
+		UpdatedAt    *time.Time               `json:"updated_at"`
+		InstanceName string                   `json:"instance_name"`
+		IsExported   bool                     `json:"is_exported"`
+		Region       scw.Region               `json:"region"`
+		SameRegion   bool                     `json:"same_region"`
+	}
+
+	opt.Fields = []*human.MarshalFieldOpt{
+		{
+			Label:     "ID",
+			FieldName: "ID",
+		},
+		{
+			Label:     "Name",
+			FieldName: "Name",
+		},
+		{
+			Label:     "Database Name",
+			FieldName: "DatabaseName",
+		},
+		{
+			Label:     "Size",
+			FieldName: "Size",
+		},
+		{
+			Label:     "Status",
+			FieldName: "Status",
+		},
+		{
+			Label:     "Instance ID",
+			FieldName: "InstanceID",
+		},
+		{
+			Label:     "Is Exported",
+			FieldName: "IsExported",
+		},
+		{
+			Label:     "Created At",
+			FieldName: "CreatedAt",
+		},
+		{
+			Label:     "Updated At",
+			FieldName: "UpdatedAt",
+		},
+		{
+			Label:     "Region",
+			FieldName: "Region",
+		},
+		{
+			Label:     "Same Region",
+			FieldName: "SameRegion",
+		},
+	}
+
+	isExported := false
+	if databaseBackup.DownloadURL != nil {
+		isExported = true
+	}
+
+	arg := customDisplayBackup{
+		ID:           databaseBackup.ID,
+		InstanceID:   databaseBackup.InstanceID,
+		DatabaseName: databaseBackup.DatabaseName,
+		Name:         databaseBackup.Name,
+		Status:       databaseBackup.Status,
+		Size:         databaseBackup.Size,
+		ExpiresAt:    databaseBackup.ExpiresAt,
+		CreatedAt:    databaseBackup.CreatedAt,
+		UpdatedAt:    databaseBackup.UpdatedAt,
+		InstanceName: databaseBackup.InstanceName,
+		IsExported:   isExported,
+		Region:       databaseBackup.Region,
+		SameRegion:   databaseBackup.SameRegion,
+	}
+	str, err := human.Marshal(arg, opt)
+	if err != nil {
+		return "", err
+	}
+	return str, nil
+}
+
 // urlExpired: indicates if the backup url is still valid after the indicated date.
 func urlExpired(expirationDate *time.Time) bool {
 	if expirationDate == nil {
