@@ -152,7 +152,7 @@ func backupScheduleMarshalerFunc(i interface{}, opt *human.MarshalOpt) (string,
 }
 
 func instanceCloneBuilder(c *core.Command) *core.Command {
-	c.WaitFunc = func(ctx context.Context, argsI, respI interface{}) (interface{}, error) {
+	c.WaitFunc = func(ctx context.Context, _, respI interface{}) (interface{}, error) {
 		api := rdb.NewAPI(core.ExtractClient(ctx))
 		return api.WaitForInstance(&rdb.WaitForInstanceRequest{
 			InstanceID:    respI.(*rdb.Instance).ID,
@@ -168,6 +168,8 @@ func instanceCloneBuilder(c *core.Command) *core.Command {
 // Caching ListNodeType response for shell completion
 var completeListNodeTypeCache *rdb.ListNodeTypesResponse
 
+var completeListEngineCache *rdb.ListDatabaseEnginesResponse
+
 func autoCompleteNodeType(ctx context.Context, prefix string) core.AutocompleteSuggestions {
 	suggestions := core.AutocompleteSuggestions(nil)
 
@@ -191,22 +193,41 @@ func autoCompleteNodeType(ctx context.Context, prefix string) core.AutocompleteS
 	return suggestions
 }
 
+func autoCompleteDatabaseEngines(ctx context.Context, prefix string) core.AutocompleteSuggestions {
+	suggestion := core.AutocompleteSuggestions(nil)
+	client := core.ExtractClient(ctx)
+	api := rdb.NewAPI(client)
+
+	if completeListEngineCache == nil {
+		res, err := api.ListDatabaseEngines(&rdb.ListDatabaseEnginesRequest{}, scw.WithAllPages())
+		if err != nil {
+			return nil
+		}
+		completeListEngineCache = res
+	}
+
+	for _, engine := range completeListEngineCache.Engines {
+		if strings.HasPrefix(engine.Name, prefix) {
+			suggestion = append(suggestion, engine.Name)
+		}
+	}
+
+	return suggestion
+}
+
 func instanceCreateBuilder(c *core.Command) *core.Command {
-	type rdbEndpointSpecPrivateNetworkCustom struct {
-		*rdb.EndpointSpecPrivateNetwork
-		EnableIpam bool `json:"enable-ipam"`
-	}
-
-	type rdbEndpointSpecCustom struct {
-		PrivateNetwork *rdbEndpointSpecPrivateNetworkCustom `json:"private-network"`
-	}
-
 	type rdbCreateInstanceRequestCustom struct {
 		*rdb.CreateInstanceRequest
 		InitEndpoints    []*rdbEndpointSpecCustom `json:"init-endpoints"`
 		GeneratePassword bool
 	}
 
+	c.ArgSpecs.AddBefore("init-endpoints.{index}.private-network.private-network-id", &core.ArgSpec{
+		Name:     "init-endpoints.{index}.load-balancer",
+		Short:    "Will configure a load-balancer endpoint along with your private network endpoint if true",
+		Required: false,
+		Default:  core.DefaultValueSetter("false"),
+	})
 	c.ArgSpecs.AddBefore("init-endpoints.{index}.private-network.private-network-id", &core.ArgSpec{
 		Name:     "init-endpoints.{index}.private-network.enable-ipam",
 		Short:    "Will configure your Private Network endpoint with Scaleway IPAM service if true",
@@ -224,10 +245,11 @@ func instanceCreateBuilder(c *core.Command) *core.Command {
 	c.ArgSpecs.GetByName("password").Required = false
 	c.ArgSpecs.GetByName("node-type").Default = core.DefaultValueSetter("DB-DEV-S")
 	c.ArgSpecs.GetByName("node-type").AutoCompleteFunc = autoCompleteNodeType
+	c.ArgSpecs.GetByName("engine").AutoCompleteFunc = autoCompleteDatabaseEngines
 
 	c.ArgsType = reflect.TypeOf(rdbCreateInstanceRequestCustom{})
 
-	c.WaitFunc = func(ctx context.Context, argsI, respI interface{}) (interface{}, error) {
+	c.WaitFunc = func(ctx context.Context, _, respI interface{}) (interface{}, error) {
 		api := rdb.NewAPI(core.ExtractClient(ctx))
 		instance, err := api.WaitForInstance(&rdb.WaitForInstanceRequest{
 			InstanceID:    respI.(createInstanceResult).Instance.ID,
@@ -265,21 +287,9 @@ func instanceCreateBuilder(c *core.Command) *core.Command {
 			fmt.Printf("\n")
 		}
 
-		for _, customEndpoint := range customRequest.InitEndpoints {
-			if customEndpoint.PrivateNetwork == nil {
-				continue
-			}
-			ipamConfig := &rdb.EndpointSpecPrivateNetworkIpamConfig{}
-			if !customEndpoint.PrivateNetwork.EnableIpam {
-				ipamConfig = nil
-			}
-			createInstanceRequest.InitEndpoints = append(createInstanceRequest.InitEndpoints, &rdb.EndpointSpec{
-				PrivateNetwork: &rdb.EndpointSpecPrivateNetwork{
-					PrivateNetworkID: customEndpoint.PrivateNetwork.PrivateNetworkID,
-					ServiceIP:        customEndpoint.PrivateNetwork.ServiceIP,
-					IpamConfig:       ipamConfig,
-				},
-			})
+		createInstanceRequest.InitEndpoints, err = endpointRequestFromCustom(customRequest.InitEndpoints)
+		if err != nil {
+			return nil, err
 		}
 
 		instance, err := api.CreateInstance(createInstanceRequest)
@@ -364,7 +374,7 @@ func instanceGetBuilder(c *core.Command) *core.Command {
 func instanceUpgradeBuilder(c *core.Command) *core.Command {
 	c.ArgSpecs.GetByName("node-type").AutoCompleteFunc = autoCompleteNodeType
 
-	c.WaitFunc = func(ctx context.Context, argsI, respI interface{}) (interface{}, error) {
+	c.WaitFunc = func(ctx context.Context, _, respI interface{}) (interface{}, error) {
 		api := rdb.NewAPI(core.ExtractClient(ctx))
 		return api.WaitForInstance(&rdb.WaitForInstanceRequest{
 			InstanceID:    respI.(*rdb.Instance).ID,
@@ -521,7 +531,7 @@ func instanceUpdateBuilder(_ *core.Command) *core.Command {
 
 			return updateInstanceResponse, nil
 		},
-		WaitFunc: func(ctx context.Context, argsI, respI interface{}) (interface{}, error) {
+		WaitFunc: func(ctx context.Context, _, respI interface{}) (interface{}, error) {
 			api := rdb.NewAPI(core.ExtractClient(ctx))
 			return api.WaitForInstance(&rdb.WaitForInstanceRequest{
 				InstanceID:    respI.(*rdb.Instance).ID,
@@ -548,7 +558,7 @@ func instanceUpdateBuilder(_ *core.Command) *core.Command {
 }
 
 func instanceDeleteBuilder(c *core.Command) *core.Command {
-	c.WaitFunc = func(ctx context.Context, argsI, respI interface{}) (interface{}, error) {
+	c.WaitFunc = func(ctx context.Context, _, respI interface{}) (interface{}, error) {
 		api := rdb.NewAPI(core.ExtractClient(ctx))
 		instance, err := api.WaitForInstance(&rdb.WaitForInstanceRequest{
 			InstanceID:    respI.(*rdb.Instance).ID,
