@@ -2,20 +2,23 @@ package rdb
 
 import (
 	"fmt"
+	"strings"
 	"testing"
 
 	"github.com/alecthomas/assert"
 	"github.com/scaleway/scaleway-cli/v2/internal/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/vpc/v2"
-	"github.com/scaleway/scaleway-sdk-go/api/ipam/v1"
 	"github.com/scaleway/scaleway-sdk-go/api/rdb/v1"
-	"github.com/scaleway/scaleway-sdk-go/scw"
 )
 
 const (
-	publicEndpoint        = "public"
-	privateEndpointIpam   = "private IPAM"
-	privateEndpointStatic = "private static"
+	baseCommand              = "scw rdb instance create node-type=DB-DEV-S is-ha-cluster=false name=%s engine=%s user-name=%s password=%s --wait"
+	privateNetworkStaticSpec = " init-endpoints.0.private-network.private-network-id={{ .PN.ID }} init-endpoints.0.private-network.service-ip={{ .IPNet }}"
+	privateNetworkIpamSpec   = " init-endpoints.0.private-network.private-network-id={{ .PN.ID }} init-endpoints.0.private-network.enable-ipam=true"
+	loadBalancerSpec         = " init-endpoints.1.load-balancer=true"
+	publicEndpoint           = "public"
+	privateEndpointIpam      = "private IPAM"
+	privateEndpointStatic    = "private static"
 )
 
 func Test_ListInstance(t *testing.T) {
@@ -41,11 +44,12 @@ func Test_CloneInstance(t *testing.T) {
 func Test_CreateInstance(t *testing.T) {
 	t.Run("Simple", core.Test(&core.TestConfig{
 		Commands: GetCommands(),
-		Cmd:      fmt.Sprintf("scw rdb instance create node-type=DB-DEV-S is-ha-cluster=false name=%s engine=%s user-name=%s password=%s --wait", name, engine, user, password),
+		Cmd:      fmt.Sprintf(baseCommand, name, engine, user, password),
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				checkEndpoints(ctx, t, []string{publicEndpoint})
+				instance := ctx.Result.(createInstanceResult).Instance
+				checkEndpoints(t, ctx.Client, instance, []string{publicEndpoint})
 			},
 		),
 		AfterFunc: core.ExecAfterCmd("scw rdb instance delete {{ .CmdResult.ID }}"),
@@ -53,57 +57,88 @@ func Test_CreateInstance(t *testing.T) {
 
 	t.Run("With password generator", core.Test(&core.TestConfig{
 		Commands: GetCommands(),
-		Cmd:      fmt.Sprintf("scw rdb instance create node-type=DB-DEV-S is-ha-cluster=false name=%s engine=%s user-name=%s generate-password=true --wait", name, engine, user),
+		Cmd:      fmt.Sprintf(strings.Replace(baseCommand, "password=%s", "generate-password=true", 1), name, engine, user),
 		// do not check the golden as the password generated locally and on CI will necessarily be different
 		Check: core.TestCheckCombine(
 			core.TestCheckExitCode(0),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				checkEndpoints(ctx, t, []string{publicEndpoint})
+				instance := ctx.Result.(createInstanceResult).Instance
+				checkEndpoints(t, ctx.Client, instance, []string{publicEndpoint})
 			},
 		),
 		AfterFunc: core.ExecAfterCmd("scw rdb instance delete {{ .CmdResult.ID }}"),
 	}))
+}
 
+func Test_CreateInstanceInitEndpoints(t *testing.T) {
 	cmds := GetCommands()
 	cmds.Merge(vpc.GetCommands())
 
 	t.Run("With static private endpoint", core.Test(&core.TestConfig{
-		Commands: cmds,
-		BeforeFunc: core.BeforeFuncCombine(
-			core.ExecStoreBeforeCmd("PrivateNetwork", "scw vpc private-network create"),
-		),
-		Cmd: fmt.Sprintf("scw rdb instance create node-type=DB-DEV-S is-ha-cluster=false name=%s engine=%s "+
-			"user-name=%s password=%s init-endpoints.0.private-network.private-network-id={{ .PrivateNetwork.ID }} "+
-			"init-endpoints.0.private-network.service-ip=172.16.4.1/22 --wait", name, engine, user, password),
+		Commands:   cmds,
+		BeforeFunc: createPN(),
+		Cmd:        fmt.Sprintf(baseCommand+privateNetworkStaticSpec, name, engine, user, password),
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				checkEndpoints(ctx, t, []string{publicEndpoint, privateEndpointStatic})
+				instance := ctx.Result.(createInstanceResult).Instance
+				checkEndpoints(t, ctx.Client, instance, []string{privateEndpointStatic})
 			},
 		),
 		AfterFunc: core.AfterFuncCombine(
 			core.ExecAfterCmd("scw rdb instance delete {{ .CmdResult.ID }} --wait"),
-			deletePrivateNetwork("PrivateNetwork"),
+			deletePrivateNetwork(),
+		),
+	}))
+
+	t.Run("With public and static private endpoint", core.Test(&core.TestConfig{
+		Commands:   cmds,
+		BeforeFunc: createPN(),
+		Cmd:        fmt.Sprintf(baseCommand+privateNetworkStaticSpec+loadBalancerSpec, name, engine, user, password),
+		Check: core.TestCheckCombine(
+			core.TestCheckGolden(),
+			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				instance := ctx.Result.(createInstanceResult).Instance
+				checkEndpoints(t, ctx.Client, instance, []string{publicEndpoint, privateEndpointStatic})
+			},
+		),
+		AfterFunc: core.AfterFuncCombine(
+			core.ExecAfterCmd("scw rdb instance delete {{ .CmdResult.ID }} --wait"),
+			deletePrivateNetwork(),
 		),
 	}))
 
 	t.Run("With IPAM private endpoint", core.Test(&core.TestConfig{
-		Commands: cmds,
-		BeforeFunc: core.BeforeFuncCombine(
-			core.ExecStoreBeforeCmd("PrivateNetwork", "scw vpc private-network create"),
-		),
-		Cmd: fmt.Sprintf("scw rdb instance create node-type=DB-DEV-S is-ha-cluster=false name=%s engine=%s "+
-			"user-name=%s password=%s init-endpoints.0.private-network.private-network-id={{ .PrivateNetwork.ID }} "+
-			"init-endpoints.0.private-network.enable-ipam=true --wait", name, engine, user, password),
+		Commands:   cmds,
+		BeforeFunc: createPN(),
+		Cmd:        fmt.Sprintf(baseCommand+privateNetworkIpamSpec, name, engine, user, password),
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				checkEndpoints(ctx, t, []string{publicEndpoint, privateEndpointIpam})
+				instance := ctx.Result.(createInstanceResult).Instance
+				checkEndpoints(t, ctx.Client, instance, []string{privateEndpointIpam})
 			},
 		),
 		AfterFunc: core.AfterFuncCombine(
 			core.ExecAfterCmd("scw rdb instance delete {{ .CmdResult.ID }} --wait"),
-			deletePrivateNetwork("PrivateNetwork"),
+			deletePrivateNetwork(),
+		),
+	}))
+
+	t.Run("With public and IPAM private endpoint", core.Test(&core.TestConfig{
+		Commands:   cmds,
+		BeforeFunc: createPN(),
+		Cmd:        fmt.Sprintf(baseCommand+privateNetworkIpamSpec+loadBalancerSpec, name, engine, user, password),
+		Check: core.TestCheckCombine(
+			core.TestCheckGolden(),
+			func(t *testing.T, ctx *core.CheckFuncCtx) {
+				instance := ctx.Result.(createInstanceResult).Instance
+				checkEndpoints(t, ctx.Client, instance, []string{publicEndpoint, privateEndpointIpam})
+			},
+		),
+		AfterFunc: core.AfterFuncCombine(
+			core.ExecAfterCmd("scw rdb instance delete {{ .CmdResult.ID }} --wait"),
+			deletePrivateNetwork(),
 		),
 	}))
 }
@@ -255,7 +290,7 @@ func Test_Connect(t *testing.T) {
 		BeforeFunc: core.BeforeFuncCombine(
 			core.BeforeFuncStoreInMeta("username", user),
 			createPN(),
-			createInstanceWithPrivateNetwork("PostgreSQL-14"),
+			createInstanceWithPrivateNetworkAndLoadBalancer("PostgreSQL-14"),
 		),
 		Cmd: "scw rdb instance connect {{ .Instance.ID }} username={{ .username }}",
 		Check: core.TestCheckCombine(
@@ -267,52 +302,6 @@ func Test_Connect(t *testing.T) {
 	}))
 }
 
-func deletePrivateNetwork(metaName string) core.AfterFunc {
-	return core.ExecAfterCmd(fmt.Sprintf("scw vpc private-network delete {{ .%s.ID }}", metaName))
-}
-
-func checkEndpoints(ctx *core.CheckFuncCtx, t *testing.T, expected []string) {
-	instance := ctx.Result.(createInstanceResult).Instance
-	ipamAPI := ipam.NewAPI(ctx.Client)
-	var foundEndpoints = map[string]bool{}
-
-	for _, endpoint := range instance.Endpoints {
-		if endpoint.LoadBalancer != nil {
-			foundEndpoints[publicEndpoint] = true
-		}
-		if endpoint.PrivateNetwork != nil {
-			ips, err := ipamAPI.ListIPs(&ipam.ListIPsRequest{
-				Region:       instance.Region,
-				ResourceID:   &instance.ID,
-				ResourceType: "rdb_instance",
-				IsIPv6:       scw.BoolPtr(false),
-			}, scw.WithAllPages())
-			if err != nil {
-				t.Errorf("could not list IPs: %v", err)
-			}
-			switch ips.TotalCount {
-			case 1:
-				foundEndpoints[privateEndpointIpam] = true
-			case 0:
-				foundEndpoints[privateEndpointStatic] = true
-			default:
-				t.Errorf("expected no more than 1 IP for instance, got %d", ips.TotalCount)
-			}
-		}
-	}
-
-	// Check that every expected endpoint got found
-	for _, e := range expected {
-		_, ok := foundEndpoints[e]
-		if !ok {
-			t.Errorf("expected a %s endpoint but got none", e)
-		}
-		delete(foundEndpoints, e)
-	}
-	// Check that no unexpected endpoint was found
-	if len(foundEndpoints) > 0 {
-		for e := range foundEndpoints {
-			t.Errorf("found a %s endpoint when none was expected", e)
-		}
-	}
+func deletePrivateNetwork() core.AfterFunc {
+	return core.ExecAfterCmd("scw vpc private-network delete {{ .PN.ID }}")
 }
